componenttools.list_leftmost_components_with_prolated_duration_at_most
======================================================================

.. autofunction:: abjad.tools.componenttools.list_leftmost_components_with_prolated_duration_at_most.list_leftmost_components_with_prolated_duration_at_most
